@@ -33,7 +33,7 @@ our @EXPORT_OK = qw(
                        ta_wrap
                );
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 # used to find/strip escape codes from string
 our $re       = qr/
@@ -238,6 +238,8 @@ sub _ta_wrap {
     #use Data::Dump::Color; my @d; for (0..$#terms) { push @d, {type=>$termst[$_], term=>$terms[$_], pterm=>$pterms[$_], termc=>$termsc[$_], termw=>$termsw[$_], } } dd \@d;
     #return;
 
+    my ($maxww, $minww);
+
     # now we perform wrapping
 
     my @res;
@@ -384,6 +386,10 @@ sub _ta_wrap {
                 for my $word (@words) {
                     my $wordw = shift @wordsw;
                     #say "D:x=$x word=$word wordw=$wordw line_has_word=$line_has_word width=$width";
+
+                    $maxww = $wordw if !defined($maxww) || $maxww < $wordw;
+                    $minww = $wordw if !defined($minww) || $minww > $wordw;
+
                     if ($x + ($line_has_word ? 1:0) + $wordw <= $width) {
                         if ($line_has_word) {
                             push @res, " ";
@@ -408,7 +414,14 @@ sub _ta_wrap {
         push @res, " " x ($width-$x) if $line_has_word && $pad;
     }
 
-    join "", @res;
+    if ($opts->{return_stats}) {
+        return [join("", @res), {
+            max_word_width => $maxww,
+            min_word_width => $minww,
+        }];
+    } else {
+        return join("", @res);
+    }
 }
 
 sub ta_wrap {
@@ -697,7 +710,7 @@ Text::ANSI::Util - Routines for text containing ANSI escape codes
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -889,6 +902,12 @@ First line indent. See Text::WideChar::Util for more details.
 If set to true, will pad each line to C<$width>. This is convenient if you need
 the lines padded, saves calls to ta_pad().
 
+=item * return_stats => BOOL (default: 0)
+
+If set to true, then instead of returning the wrapped string, function will
+return C<< [$wrapped, $stats] >> where C<$stats> is a hash containing some
+information like C<max_word_width>, C<min_word_width>.
+
 =back
 
 Performance: ~750/s on my Core i5-2400 3.1GHz desktop for a ~1KB of text (with
